@@ -353,25 +353,22 @@ dock (void)
      	gdk_pixmap_unref(gdkpixmap);
      	gdk_bitmap_unref(gdkbitmap);
      	evbox = gtk_event_box_new();
-
      	gtk_tooltips_set_tip(tips,evbox,"click here for more options","private");
      	gtk_widget_set_events(evbox, GDK_BUTTON_PRESS);
      	gtk_signal_connect(GTK_OBJECT(evbox), "button_press_event", GTK_SIGNAL_FUNC(on_eventbox_click), NULL);
      
      	gtk_container_add(GTK_CONTAINER(evbox), pixmap);
      	gtk_box_pack_start(GTK_BOX(box),evbox,FALSE,FALSE,FALSE);
-	gtk_widget_show_all(box);
-     
+	
      	box = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dockwin)->vbox), box, FALSE, FALSE, 0);
 
 	use_font_button = gtk_check_button_new_with_label("Use font: ");
 	gtk_box_pack_start(GTK_BOX(box), use_font_button, FALSE, FALSE, 0);
-	gtk_widget_show(use_font_button);
-     
+
 	font_entry = gtk_entry_new();
 	gtk_box_pack_start(GTK_BOX(box), font_entry, TRUE, TRUE, 0);
-	gtk_widget_show(font_entry);
+
 	if (newfont)
 	{
 		gtk_entry_set_text (GTK_ENTRY(font_entry), newfont);
@@ -400,23 +397,21 @@ dock (void)
 	browse = gtk_button_new_with_label("Browse...");
 	gtk_signal_connect(GTK_OBJECT(browse), "clicked", GTK_SIGNAL_FUNC(font_browse_clicked), NULL);
 	gtk_box_pack_start(GTK_BOX(box), browse, FALSE, FALSE, 0);
-	
+
 	button = gtk_button_new_with_label("Apply");
 	gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(apply_clicked),NULL);
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG (dockwin)->action_area),button,TRUE,TRUE,FALSE);
-	gtk_widget_show(button);
-     
+
 	button = gtk_button_new_with_label("Preview");
 	gtk_signal_connect(GTK_OBJECT(button),"clicked",GTK_SIGNAL_FUNC(preview_clicked),NULL);
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG (dockwin)->action_area),button,TRUE,TRUE,FALSE);
-	gtk_widget_show(button);
-     
+
 	install_button = gtk_button_new_with_label("Install New Theme");
 	gtk_signal_connect(GTK_OBJECT(install_button), "clicked", GTK_SIGNAL_FUNC(install_clicked), NULL);
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG (dockwin)->action_area),install_button,TRUE,TRUE,FALSE);
 
-	gtk_widget_show(dockwin);
-
+	gtk_widget_show_all(dockwin);
+	hide_stuff();
 }
 
 void on_eventbox_click()
@@ -500,9 +495,9 @@ preview (gchar *rc_file)
 	     
 		while (gtk_events_pending())
 	     		gtk_main_iteration();
-		usleep(50000);
+		
 	}
-            
+     
      	pclose(pipe);
 	g_free (line);
 	g_free (path);
